use crate::config::Config;
use actix_web::web::Data;
use actix_web::*;

pub(crate) async fn build_site(
    content: String,
    title: &str,
    disable_color: bool,
    shadow: bool,
    config: &Data<Config>,
) -> HttpResponse<String> {
    const BOOTSTRAP: &str = r#"
<link href="/bootstrap.min.css" rel="stylesheet">
<link href="/bootstrap-icons.css" rel="stylesheet">
<link href="/bootstrap.bundle.min.js" rel="stylesheet">
    "#;

    let mut c_class = "bg-dark text-white justify-content-center text-center".to_string();
    let mut c_style = "".to_string();
    let mut g_style = "a {text-decoration: none; font-weight: bold; color: white}".to_string();
    if !disable_color {
        if let (Some(fg), Some(bg)) = (config.fg_color(), config.bg_color()) {
            c_class = "justify-content-center text-center".to_string();
            c_style = format!("background: {bg}; color: {fg};");
            g_style = format!("a {{text-decoration: none; font-weight: bold; color: {fg}}}");
        }
    }
    if std::path::Path::new("/config/wall.avif").exists() {
        c_style.push_str("background-image: url('assets/wall');background-size:cover;");
    }
    if shadow {
        c_style.push_str("text-shadow: 1px 1px 3px black;");
    }

    let r = format!(
        "
<!DOCTYPE html>
<html>
<head>
<title> {title} </title>
<meta name=\"viewport\" content=\"user-scalable=no, width=device-width, initial-scale=1.0\">
{BOOTSTRAP}
</head>
<body style=\"{c_style}\" class=\"{c_class}\">
<style>
{g_style}
</style>
{content}
</body>
</html>
    "
    );

    return HttpResponse::Ok().message_body(r).unwrap();
}
